@@ -191,9 +191,8 @@ void YouTube::checkYouTubeVideoInfoPage() {
 #endif
         }
         else {
-            QString formats = response.section("&", 0, 0);
-            formats.replace(QRegExp("%2C(\\w+%3D1%26|)" + separator), "," + separator);
-            this->parseYouTubeVideoPage(QScriptValue(), formats);
+            response = response.section("&", 0, 0).replace("%2C", ",");
+            this->parseYouTubeVideoPage(QScriptValue(), response);
         }
     }
 
